boofun.core.representations.packed\_truth\_table
================================================

.. automodule:: boofun.core.representations.packed_truth_table


   .. rubric:: Functions

   .. autosummary::

      create_packed_truth_table
      is_bitarray_available
      memory_comparison

   .. rubric:: Classes

   .. autosummary::

      PackedTruthTableRepresentation
